@@ -2,22 +2,11 @@ from . import mmm as mmm
 from astropy.io import fits
 import numpy as np
 import sys
-from matplotlib import pyplot as plt
 import RRGtools as at
-import ipdb as pdb
-def measure_moms(fits_image, sex_catalog, outfile,
-                     width=None,
-                     saturation=800000000, badval=-99,
-                     cut_off=2.5, fieldback=0, mult=1,
-                     min_rad=1.5, startx=0, starty=0,
-                     verbose=False, weight_image=None,
-                     wt_ext=0, nocenter=0,
-                     sgm_im='null',
-                     object_catalogue=None,
-                     bad_val=-99, regfile=None,
-                     skymed=None, skysd=None,
-                     return_moms=True, quiet=False,
-                     jwst=False, error=0.01, min_it=500, **kwargs):
+import json
+from tqdm import tqdm
+
+def measure_moms(fits_image, sex_catalog, outfile, verbose=False, quiet=False, **kwargs):
                      
     '''
     ;
@@ -39,7 +28,6 @@ def measure_moms(fits_image, sex_catalog, outfile,
     ;   width- gaussian window function width, if not input is calculated from area
     ;   saturation,bad_value are saturation level and value of pixels not to use (outside image)
     ;   cut_off- cut_off for measuring objects default is 2.5x width
-    ;   fieldback -1 means use a field backgroup as calculated by IDL SKY, 0(default) uses object back from SEx
     ;   mult- multiplier used to find gaussian width from area
     ;   min_rad- stellar radius
     ;   startx, starty- lower left corner of image in pixel values, default to zero
@@ -65,20 +53,67 @@ def measure_moms(fits_image, sex_catalog, outfile,
     ENDIF
     ;
     '''
-    img_file = fits.open( fits_image )
-    print(fits_image)
-                   
-    if jwst:
-        extension = 1
-        expTimeName = 'XPOSURE'
+    if 'saturation' not in kwargs.keys():
+        kwargs['saturation'] = 800000000
+    if 'bad_val' not in kwargs.keys():
+        kwargs['bad_val'] = -99
+    if 'cut_off' not in kwargs.keys():
+        kwargs['cut_off'] = 2.5
+    if 'mult' not in kwargs.keys():
+        kwargs['mult'] = 1               
+    if 'min_rad' not in kwargs.keys():
+        kwargs['min_rad'] = 1.5           
+    if 'start' not in kwargs.keys():
+        startx, starty = 0, 0
     else:
-        extension = 0
-        expTimeName = 'EXPTIME'
+        startx, starty = kwargs['start']
+        
+    if 'weight_file' not in kwargs.keys():
+        kwargs['weight_file'] =  None  
+    if 'nocenter' not in kwargs.keys():
+        kwargs['nocenter'] = 0. 
+            
+    if 'sgm_im' not in kwargs.keys():
+        kwargs['sgm_im'] = 'null'
+   
+    if 'object_catalogue' not in kwargs.keys():
+        object_catalogue = None
+    else:
+        object_catalogue = kwargs['object_catalogue']
+     
+    if 'regfile' not in kwargs.keys():
+        kwargs['regfile'] = None
 
-    imhead = img_file[extension].header
-    img = img_file[extension].data
+    if 'sky' not in kwargs.keys():
+        skymed, skysd, skysw = None, None, None
+    else:
+        skymed, skysd, skysw = kwargs['sky']['skymed'], kwargs['sky']['skysd'], kwargs['sky']['skysw']
+        
+    if 'return_moms' not in kwargs.keys():
+        kwargs['return_moms'] = True
+        
+    if 'error' not in kwargs.keys():
+        kwargs['error'] =  0.01
+        
+    if 'min_it' not in kwargs.keys():
+        kwargs['min_it'] =  500
+        
+                    
+                    
+                    
+                    
+    img_file = fits.open( fits_image )
+
+
+    if 'fits_extension' not in kwargs.keys():
+        kwargs['fits_extension'] = 0
+    if 'expTimeName'  not in kwargs.keys():
+        kwargs['expTimeName'] = 'EXPTIME'
     
-    exp_time = imhead[expTimeName]
+    imhead = img_file[kwargs['fits_extension']].header
+    img = img_file[kwargs['fits_extension']].data
+    
+    exp_time = imhead[kwargs['expTimeName']]
  
     #What is mmm?
     if (skymed is None )| \
@@ -111,10 +146,10 @@ def measure_moms(fits_image, sex_catalog, outfile,
     ysize= imhead['NAXIS2']
     xsize= imhead['NAXIS1']
 
-    if weight_image is None:
+    if kwargs['weight_file'] is None:
         wt_image = np.ones( img.shape)
     else:
-        wt_image = fits.open( weight_image )[0].data
+        wt_image = fits.open( kwargs['weight_file'] )[0].data
 
 
 
@@ -126,8 +161,8 @@ def measure_moms(fits_image, sex_catalog, outfile,
 
     
 
-    if (sgm_im != 'null') & (fieldback == 1):
-        seg_file = fits.open(sgm_im)
+    if (kwargs['sgm_im'] != 'null'):
+        seg_file = fits.open(kwargs['sgm_im'])
         seg = seg_file[0].data
         shdr = seg_file[0].header
         '''
@@ -137,17 +172,14 @@ def measure_moms(fits_image, sex_catalog, outfile,
         '''
     if not 'radius' in kwargs:
         area=np.pi*object_catalogue['A_IMAGE']*object_catalogue['B_IMAGE']
-        radius = np.sqrt( area / np.pi )*mult
+        radius = np.sqrt( area / np.pi )*kwargs['mult']
     else:
         radius = kwargs['radius']
     
-    radius[ radius < min_rad ] = min_rad
+    radius[ radius < kwargs['min_rad'] ] = kwargs['min_rad']
 
-    
-    if width is not None:
-        radius=np.zeros(nGalaxies) + width
         
-    cut_rad = radius*cut_off # cut off radius of object
+    cut_rad = radius*kwargs['cut_off'] # cut off radius of object
     offedge=0 #;number of objects off the endge initially
     centerprob=0 # number of objects with centroiding problems
     badpix_prob=0 #number of objects with bad pixels
@@ -155,12 +187,8 @@ def measure_moms(fits_image, sex_catalog, outfile,
     
     galaxy_moments = moms( nGalaxies, radius=radius )
 
-
-    for i in range( nGalaxies ):
-        if (not verbose) & (not quiet):
-            sys.stdout.write("Measuring moment of object: %i/%i\r" % \
-                                 (i,nGalaxies))
-            sys.stdout.flush()
+    print("Measuring Object Moments")
+    for i in tqdm(range( nGalaxies )):
         
         #following changed by jrhodes to account for different indexing in SExtractor and IDL
        
@@ -190,10 +218,10 @@ def measure_moms(fits_image, sex_catalog, outfile,
             galaxy_moments.prob[i] += 1
             
 
-        if nocenter == 0:
-            while  ((np.abs(deltax) > error) |  \
-              (np.abs(deltay) > error)) & \
-               (count < min_it) & (go_on == 1) :
+        if kwargs['nocenter']  == 0:
+            while  ((np.abs(deltax) > kwargs['error']) |  \
+              (np.abs(deltay) > kwargs['error'])) & \
+               (count < kwargs['min_it']) & (go_on == 1) :
                 #These are needed for all moments
                 #Cut out a postage stamp of the image
                 begin_x = np.round(xc-cut_rad[i]-1).astype(int)
@@ -302,8 +330,8 @@ def measure_moms(fits_image, sex_catalog, outfile,
         if go_on == 1:
 
 
-            if (np.any(postage_stamp > saturation)) | \
-                (np.any(postage_stamp == bad_val)) | \
+            if (np.any(postage_stamp > kwargs['saturation'])) | \
+                (np.any(postage_stamp == kwargs['bad_val'])) | \
                 (np.any(postage_weight == 0)):
                 go_on = 0
                 galaxy_moments.prob[i] += 4
@@ -384,17 +412,14 @@ def measure_moms(fits_image, sex_catalog, outfile,
     #Append some needed things
     #Can just append the RA as this is not the same as the pixel position
     #Need to find the re-centred RA
-    if jwst:
-        recentred_ra, recentred_dec = \
-              at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y, extension=extension)
-    else:
-        recentred_ra, recentred_dec = \
-              at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y)
-     
+
+    recentred_ra, recentred_dec = \
+              at.pix2deg( fits_image, galaxy_moments.x, galaxy_moments.y, extension=kwargs['fits_extension'])
+
     galaxy_moments.ra = recentred_ra
     galaxy_moments.dec = recentred_dec
    
-    galaxy_moments.calc_e1e2( mult_rad=mult)     
+    galaxy_moments.calc_e1e2( mult_rad=kwargs['mult'])     
     #log this stuff as i want this for the star galaxy separation
     galaxy_moments['skymed'][:] = skymed
     galaxy_moments['skysd'][:] = skysd
@@ -404,10 +429,10 @@ def measure_moms(fits_image, sex_catalog, outfile,
 
     galaxy_moments.write_to_fits( object_catalogue, outfile )
 
-    if regfile is not None:
-        galaxy_moments.fits_to_ellipse( regfile)
+    if kwargs['regfile'] is not None:
+        galaxy_moments.fits_to_ellipse( kwargs['regfile'] )
     
-    if return_moms:
+    if kwargs['return_moms']:
         return fits.open(outfile)[1].data
 
 class moms( dict ):
